import { select, 
        geoPath, 
        geoNaturalEarth1,
        scaleOrdinal,
        schemeRdYlGn,
        zoom,
        event } from 'd3';
import { feature } from 'topojson';
import { loadAndProcessData } from './loadAndProcessData.js';
import { colorLegend } from './colorLegend.js';

const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');

const projection = geoNaturalEarth1().clipExtent([[0,0],[width,height]]);

const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

const colorLegendG = svg.append('g')
	.attr('transform', `translate(50,250)`)

g.append('path')
	.attr('class', 'sphere')
	.attr('d', pathGenerator({type:'Sphere'}))

svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));

const colorScale = scaleOrdinal();

const colorValue = d => d.properties.economy

loadAndProcessData().then(countries => {
  const paths = g.selectAll('path')
  	.data(countries.features)
  
  colorScale
    .domain(countries.features.map(colorValue))
  	.domain(colorScale.domain().sort().reverse())
  	.range(schemeRdYlGn[colorScale.domain().length]);
  
  colorLegendG
  	.call(colorLegend, {
      colorScale,
      spacing: 30,
      circleRadius: 10,
      textOffset: 20
  })
  
  paths.enter().append('path')
  	.attr('class', 'country')
  	.attr('d', d => pathGenerator(d))
  	.attr('fill', d => colorScale(colorValue(d)))
  .append('title')
  	.text(d => d.properties.name + '\n' + colorValue(d));
});